Molecular line emissions from pre main sequence objects - Open Research Online
Author: Saraceno, P.
Description: We present some preliminary results obtained with the LWS G.T. programme on the study of young objects driving molecular outflows. In particular, we discuss the importance of molecular emission in these sources and address the role of the H<sub>2</sub>0 cooling.
Date: 1997

Skip to content

- OU Home
- Study at the OU
- About the OU
- Research at the OU
- Search
- Contact

Accessibility

# Molecular line emissions from pre main sequence objects Saraceno, P.; Benedettini, M.; Caux, E.; Ceccarelli, M. C.; Clegg, P. E.; Correia, J. C.; di Giorgio, A. M.; Giannini, T.; Griffin, M. J.; Leeks, S. J.; Liseau, R.; Lorenzetti, D.; Molinari, S.; Nisini, B.; Smith, H.; Spinoglio, L.; Tomassi, E. and White, G. J. (1997). Molecular line emissions from pre main sequence objects. In: The first ISO workshop on Analytical Spectroscopy, 6-8 October 1997, Madrid, Spain, p. 291. Full text available as:
Preview
| PDF (Version of Record) - Requires a PDF viewer such as GSview, Xpdf or Adobe Acrobat Reader Download (239Kb)
URL: | http://cdsads.u-strasbg.fr/abs/1997ESASP.419..291S
Google Scholar: | Look up in Google Scholar
## Abstract We present some preliminary results obtained with the LWS G.T. programme on the study of young objects driving molecular outflows. In particular, we discuss the importance of molecular emission in these sources and address the role of the H20 cooling.
Item Type: | Conference Item
Copyright Holders: | 1997 European Space Agency
Extra Information: | Proceedings of the first ISO workshop on Analytical Spectroscopy, Madrid, Spain, 6-8 October 1997. Editors: A.M. Heras, K. Leech, N. R. Trams, and Michael Perry. Noordwijk, The Netherlands : ESA Publications Division, c1997. (ESA SP-419), 1997., pp.291-292
Academic Unit/Department: | Science > Physical Sciences
Interdisciplinary Research Centre: | Centre for Earth, Planetary, Space and Astronomical Research (CEPSAR)
Item ID: | 32696
Depositing User: | Glenn White
Date Deposited: | 22 Mar 2012 10:56
Last Modified: | 22 Mar 2012 22:37
URI: | http://oro.open.ac.uk/id/eprint/32696
### Actions (login may be required)
| View Item
| Report issue / request change

Policies | Disclaimer

- New to OU
- OU on TV
- For Alumni
- For Employers
- Privacy
- Copyright
- Jobs
- News
- Cymraeg

© The Open University + 44 (0)870 333 4340 general-enquiries@open.ac.uk